package org.diagbot.graphWeb.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import org.diagbot.graph.jdbc.DriverManager;
import org.diagbot.graph.jdbc.Neo4jAPI;
import org.diagbot.graphWeb.work.FeatureRate;
import org.diagbot.graphWeb.work.ParamsDataProxy;
import org.diagbot.graphWeb.work.ResponseData;
import org.diagbot.graphWeb.work.SearchData;
import org.diagbot.nlp.feature.FeatureAnalyze;
import org.diagbot.nlp.feature.FeatureType;
import org.diagbot.pub.api.Response;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import java.util.*;

@Controller
@RequestMapping("/graph")
public class PushController {
    @RequestMapping(value = "/push", method = RequestMethod.POST)
    @ResponseBody
    public Response<ResponseData> bayesPageData(HttpServletRequest request, @RequestBody SearchData searchData) throws Exception {
        return calculate(request, searchData);
    }
    public Response<ResponseData> calculate(HttpServletRequest request, SearchData searchData) throws Exception {
        Response<ResponseData> response = new Response();
        ResponseData responseData = new ResponseData();
        ParamsDataProxy paramsDataProxy = new ParamsDataProxy();
        paramsDataProxy.createSearchData(request,searchData);
        List<String> inputList = new ArrayList<>();
        Map<String, Map<String, String>> inputs = searchData.getInputs();
        Set<String> ss = inputs.keySet();
        inputList.addAll(ss);
        Neo4jAPI neo4jAPI = new Neo4jAPI(DriverManager.newDrive());
        //处理化验数据
        JSONArray jsonArray = JSONArray.parseArray(JSON.toJSONString(searchData.getLisArr()));
        List<String> lisResult = neo4jAPI.AnalysisLISResult(jsonArray);
        inputList.addAll(lisResult);
       /* for (String s:
            inputList ) {
            System.out.println(s);
        }*/
        //计算诊断
        Map<String, String> condition = neo4jAPI.getCondition((String[]) inputList.toArray(new String[inputList.size()]));
        List<FeatureRate> featureRates = new ArrayList<>();
        for (Map.Entry<String,String> d:condition.entrySet()
             ) {
            FeatureRate featureRate = new FeatureRate();
            featureRate.setFeatureName(d.getKey());
            featureRate.setExtraProperty("");
            featureRate.setDesc(d.getValue());
            featureRate.setRate("");
            featureRates.add(featureRate);
        }

        //走治疗
        if(searchData.getDiag().trim()!=null){
            String diag = searchData.getDiag();
            Map<String, JSONObject> mulDiseaseTreat = neo4jAPI.getMulDiseaseTreat_2(diag, String.join(",", inputList));
            responseData.setTreat(mulDiseaseTreat);
        }
        responseData.setDis(featureRates);
        response.setData(responseData);
        responseData.setInputs(searchData.getInputs());
        return response;
    }
}

